Index: third_party/protobuf/src/google/protobuf/unittest_import_proto3.proto |
diff --git a/third_party/protobuf/src/google/protobuf/unittest_import.proto b/third_party/protobuf/src/google/protobuf/unittest_import_proto3.proto |
similarity index 85% |
copy from third_party/protobuf/src/google/protobuf/unittest_import.proto |
copy to third_party/protobuf/src/google/protobuf/unittest_import_proto3.proto |
index c115b11171afaa03d7ee6aeedc7506689cfd7038..59673eaf9d43bd15e89d2a05f2b920a7824cba1e 100644 |
--- a/third_party/protobuf/src/google/protobuf/unittest_import.proto |
+++ b/third_party/protobuf/src/google/protobuf/unittest_import_proto3.proto |
@@ -1,6 +1,6 @@ |
// Protocol Buffers - Google's data interchange format |
// Copyright 2008 Google Inc. All rights reserved. |
-// http://code.google.com/p/protobuf/ |
+// https://developers.google.com/protocol-buffers/ |
// |
// Redistribution and use in source and binary forms, with or without |
// modification, are permitted provided that the following conditions are |
@@ -32,8 +32,9 @@ |
// Based on original Protocol Buffers design by |
// Sanjay Ghemawat, Jeff Dean, and others. |
// |
-// A proto file which is imported by unittest.proto to test importing. |
+// A proto file which is imported by unittest_proto3.proto to test importing. |
+syntax = "proto3"; |
// We don't put this in a package within proto2 because we need to make sure |
// that the generated code doesn't depend on being in the proto2 namespace. |
@@ -42,21 +43,24 @@ |
package protobuf_unittest_import; |
option optimize_for = SPEED; |
+option cc_enable_arenas = true; |
-// Excercise the java_package option. |
+// Exercise the java_package option. |
option java_package = "com.google.protobuf.test"; |
+option csharp_namespace = "Google.Protobuf.TestProtos"; |
// Do not set a java_outer_classname here to verify that Proto2 works without |
// one. |
// Test public import |
-import public "google/protobuf/unittest_import_public.proto"; |
+import public "google/protobuf/unittest_import_public_proto3.proto"; |
message ImportMessage { |
- optional int32 d = 1; |
+ int32 d = 1; |
} |
enum ImportEnum { |
+ IMPORT_ENUM_UNSPECIFIED = 0; |
IMPORT_FOO = 7; |
IMPORT_BAR = 8; |
IMPORT_BAZ = 9; |